
/*
  Copyright (C) 2002, 2005, 2006  Dmitry V. Levin <ldv@altlinux.org>

  The next_element declaration.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
*/

#ifndef NEXTELEM_H__
#define NEXTELEM_H__

extern const char *next_element(const char *new_path);

#endif /* NEXTELEM_H__ */
